@@ -1,11 +1,11 @@
 use strict;
 use warnings;
 package BenchmarkAnything::Storage::Frontend::Tools;
-BEGIN {
-  $BenchmarkAnything::Storage::Frontend::Tools::AUTHORITY = 'cpan:SCHWIGON';
-}
+# git description: v0.010-5-g13b856b
+
+our $AUTHORITY = 'cpan:SCHWIGON';
 # ABSTRACT: Access a BenchmarkAnything store with cmdline tools
-$BenchmarkAnything::Storage::Frontend::Tools::VERSION = '0.010';
+$BenchmarkAnything::Storage::Frontend::Tools::VERSION = '0.011';
 1;
 
 __END__
@@ -24,7 +24,7 @@ Steffen Schwigon <ss5@renormalist.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Steffen Schwigon.
+This software is copyright (c) 2016 by Steffen Schwigon.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
